@@ -1,20 +1,33 @@
+"""
+Main CLI entrypoint.
+"""
 import sys
 
+
 def print_info() -> None:
+    """
+    Print package info to stdout.
+    """
     print(
-        "Type annotations for boto3 1.17.54\n"
-        "Version:         1.17.54.0\n"
-        "Builder version: 4.6.0\n"
+        "Type annotations for boto3 1.18.47\n"
+        "Version:         1.18.47\n"
+        "Builder version: 5.3.1\n"
         "Docs:            https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
 
 
 def print_version() -> None:
-    print("1.17.54.0")
+    """
+    Print package version to stdout.
+    """
+    print("1.18.47")
 
 
 def main() -> None:
+    """
+    Main CLI entrypoint.
+    """
     if "--version" in sys.argv:
         return print_version()
     print_info()
